@@ -134,9 +134,22 @@ PYTORCHDDP_SUPPORTED_FRAMEWORK_VERSIONS = [
     "1.12.0",
 ]
 
+
+TORCH_DISTRIBUTED_SUPPORTED_FRAMEWORK_VERSIONS = ["1.11", "1.11.0"]
+
+
+TRAINIUM_SUPPORTED_DISTRIBUTION_STRATEGIES = ["torch_distributed"]
+
+
 SMDISTRIBUTED_SUPPORTED_STRATEGIES = ["dataparallel", "modelparallel"]
 
 
+GRAVITON_ALLOWED_TARGET_INSTANCE_FAMILY = ["c6g", "t4g", "r6g", "m6g"]
+
+
+GRAVITON_ALLOWED_FRAMEWORKS = set(["tensorflow", "pytorch", "xgboost", "sklearn"])
+
+
 def validate_source_dir(script, directory):
     """Validate that the source directory exists and it contains the user script.
 
@@ -165,12 +178,12 @@ def validate_source_code_input_against_pipeline_variables(
     """Validate source code input against pipeline variables
 
     Args:
-        entry_point (str, PipelineVariable): The path to the local Python source file that
+        entry_point (str or PipelineVariable): The path to the local Python source file that
             should be executed as the entry point to training (default: None).
-        source_dir (str, PipelineVariable): The Path to a directory with any other
+        source_dir (str or PipelineVariable): The Path to a directory with any other
             training source code dependencies aside from the entry point file (default: None).
         git_config (Dict[str, str]): Git configurations used for cloning files (default: None).
-        enable_network_isolation (bool, PipelineVariable): Specifies whether container will run
+        enable_network_isolation (bool or PipelineVariable): Specifies whether container will run
             in network isolation mode (default: False).
     """
     if is_pipeline_variable(enable_network_isolation) or enable_network_isolation is True:
@@ -410,6 +423,8 @@ def framework_name_from_image(image_uri):
             '<account>.dkr.ecr.<region>.amazonaws.com/sagemaker-rl-<fw>:<rl_toolkit><rl_version>-<device>-<py_ver>'
             current:
             '<account>.dkr.ecr.<region>.amazonaws.com/<fw>-<image_scope>:<fw_version>-<device>-<py_ver>'
+            current:
+            '<account>.dkr.ecr.<region>.amazonaws.com/sagemaker-xgboost:<fw_version>-<container_version>'
 
     Returns:
         tuple: A tuple containing:
@@ -450,6 +465,16 @@ def framework_name_from_image(image_uri):
     legacy_match = legacy_name_pattern.match(sagemaker_match.group(9))
     if legacy_match is not None:
         return (legacy_match.group(1), legacy_match.group(2), legacy_match.group(4), None)
+
+    # sagemaker-xgboost images are tagged with two aliases, e.g.:
+    # 1. Long tag: "315553699071.dkr.ecr.us-west-2.amazonaws.com/sagemaker-xgboost:1.5-1-cpu-py3"
+    # 2. Short tag: "315553699071.dkr.ecr.us-west-2.amazonaws.com/sagemaker-xgboost:1.5-1"
+    # Note 1: Both tags point to the same image
+    # Note 2: Both tags have full GPU capabilities, despite "cpu" delineation in the long tag
+    short_xgboost_tag_pattern = re.compile(r"^sagemaker-(xgboost):(.*)$")
+    short_xgboost_tag_match = short_xgboost_tag_pattern.match(sagemaker_match.group(9))
+    if short_xgboost_tag_match is not None:
+        return (short_xgboost_tag_match.group(1), "py3", short_xgboost_tag_match.group(2), None)
     return None, None, None, None
 
 
@@ -459,12 +484,16 @@ def framework_version_from_tag(image_tag):
     Args:
         image_tag (str): Image tag, which should take the form
             '<framework_version>-<device>-<py_version>'
+            '<xgboost_version>-<container_version>'
 
     Returns:
         str: The framework version.
     """
     tag_pattern = re.compile(r"^(.*)-(cpu|gpu)-(py2|py3\d*)$")
     tag_match = tag_pattern.match(image_tag)
+    if tag_match is None:
+        short_xgboost_tag_pattern = re.compile(r"^(\d\.\d+\-\d)$")
+        tag_match = short_xgboost_tag_pattern.match(image_tag)
     return None if tag_match is None else tag_match.group(1)
 
 
@@ -575,7 +604,7 @@ def validate_smdistributed(
     if "smdistributed" not in distribution:
         # Distribution strategy other than smdistributed is selected
         return
-    if is_pipeline_variable(instance_type):
+    if is_pipeline_variable(instance_type) or is_pipeline_variable(image_uri):
         # The instance_type is not available in compile time.
         # Rather, it's given in Pipeline execution time
         return
@@ -685,7 +714,13 @@ def _validate_smdataparallel_args(
 
 
 def validate_distribution(
-    distribution, instance_groups, framework_name, framework_version, py_version, image_uri, kwargs
+    distribution,
+    instance_groups,
+    framework_name,
+    framework_version,
+    py_version,
+    image_uri,
+    kwargs,
 ):
     """Check if distribution strategy is correctly invoked by the user.
 
@@ -751,6 +786,10 @@ def validate_distribution(
                     f"Invalid training instance group {train_instance_group.instance_group_name} !"
                 )
             instance_type = train_instance_group.instance_type
+            validate_distribution_for_instance_type(
+                instance_type=instance_type,
+                distribution=distribution,
+            )
             validate_smdistributed(
                 instance_type=instance_type,
                 framework_name=framework_name,
@@ -759,13 +798,23 @@ def validate_distribution(
                 distribution=distribution,
                 image_uri=image_uri,
             )
-            validate_pytorch_distribution(
-                distribution=distribution,
-                framework_name=framework_name,
-                framework_version=framework_version,
-                py_version=py_version,
-                image_uri=image_uri,
-            )
+            if framework_name and framework_name == "pytorch":
+                # We need to validate only for PyTorch framework
+                validate_pytorch_distribution(
+                    distribution=distribution,
+                    framework_name=framework_name,
+                    framework_version=framework_version,
+                    py_version=py_version,
+                    image_uri=image_uri,
+                )
+                validate_torch_distributed_distribution(
+                    instance_type=instance_type,
+                    distribution=distribution,
+                    framework_version=framework_version,
+                    py_version=py_version,
+                    image_uri=image_uri,
+                    entry_point=kwargs["entry_point"],
+                )
             warn_if_parameter_server_with_multi_gpu(
                 training_instance_type=instance_type, distribution=distribution
             )
@@ -777,6 +826,10 @@ def validate_distribution(
         instance_type = renamed_kwargs(
             "train_instance_type", "instance_type", kwargs.get("instance_type"), kwargs
         )
+        validate_distribution_for_instance_type(
+            instance_type=instance_type,
+            distribution=distribution,
+        )
         validate_smdistributed(
             instance_type=instance_type,
             framework_name=framework_name,
@@ -785,19 +838,63 @@ def validate_distribution(
             distribution=distribution,
             image_uri=image_uri,
         )
-        validate_pytorch_distribution(
-            distribution=distribution,
-            framework_name=framework_name,
-            framework_version=framework_version,
-            py_version=py_version,
-            image_uri=image_uri,
-        )
+        if framework_name and framework_name == "pytorch":
+            # We need to validate only for PyTorch framework
+            validate_pytorch_distribution(
+                distribution=distribution,
+                framework_name=framework_name,
+                framework_version=framework_version,
+                py_version=py_version,
+                image_uri=image_uri,
+            )
+            validate_torch_distributed_distribution(
+                instance_type=instance_type,
+                distribution=distribution,
+                framework_version=framework_version,
+                py_version=py_version,
+                image_uri=image_uri,
+                entry_point=kwargs["entry_point"],
+            )
         warn_if_parameter_server_with_multi_gpu(
             training_instance_type=instance_type, distribution=distribution
         )
     return distribution
 
 
+def validate_distribution_for_instance_type(instance_type, distribution):
+    """Check if the provided distribution strategy is supported for the instance_type
+
+    Args:
+        instance_type (str): A string representing the type of training instance selected.
+        distribution (dict): A dictionary with information to enable distributed training.
+    """
+    err_msg = ""
+    if isinstance(instance_type, str):
+        match = re.match(r"^ml[\._]([a-z\d]+)\.?\w*$", instance_type)
+        if match and match[1].startswith("trn"):
+            keys = list(distribution.keys())
+            if len(keys) == 0:
+                return
+            if len(keys) == 1:
+                distribution_strategy = keys[0]
+                if distribution_strategy != "torch_distributed":
+                    err_msg += (
+                        f"Provided distribution strategy {distribution_strategy} is not supported"
+                        " for Trainium instances.\n"
+                        "Please specify one of the following supported distribution strategies:"
+                        f" {TRAINIUM_SUPPORTED_DISTRIBUTION_STRATEGIES} \n"
+                    )
+            elif len(keys) > 1:
+                err_msg += (
+                    "Multiple distribution strategies are not supported for Trainium instances.\n"
+                    "Please specify one of the following supported distribution strategies:"
+                    f" {TRAINIUM_SUPPORTED_DISTRIBUTION_STRATEGIES} "
+                )
+
+    if err_msg:
+        raise ValueError(err_msg)
+
+
 def validate_pytorch_distribution(
     distribution, framework_name, framework_version, py_version, image_uri
 ):
@@ -855,6 +952,86 @@ def validate_pytorch_distribution(
         raise ValueError(err_msg)
 
 
+def validate_torch_distributed_distribution(
+    instance_type,
+    distribution,
+    framework_version,
+    py_version,
+    image_uri,
+    entry_point,
+):
+    """Check if torch_distributed distribution strategy is correctly invoked by the user.
+
+    Args:
+        instance_type (str): A string representing the type of training instance selected.
+        distribution (dict): A dictionary with information to enable distributed training.
+            (Defaults to None if distributed training is not enabled.) For example:
+
+            .. code:: python
+
+                {
+                    "torch_distributed": {
+                        "enabled": True
+                    }
+                }
+        framework_version (str): A string representing the framework version selected.
+        py_version (str): A string representing the python version selected.
+        image_uri (str): A string representing a Docker image URI.
+        entry_point (str or PipelineVariable): The absolute or relative path to the local Python
+            source file that should be executed as the entry point to
+            training.
+
+    Raises:
+        ValueError: if
+            `py_version` is not python3 or
+            `framework_version` is not in TORCH_DISTRIBUTED_SUPPORTED_FRAMEWORK_VERSIONS
+    """
+
+    torch_distributed_enabled = False
+    if "torch_distributed" in distribution:
+        torch_distributed_enabled = distribution.get("torch_distributed").get("enabled", False)
+    if not torch_distributed_enabled:
+        # Distribution strategy other than torch_distributed is selected
+        return
+
+    err_msg = ""
+    if not image_uri:
+        # ignore framework_version and py_version if image_uri is set
+        # in case image_uri is not set, then both are mandatory
+        if framework_version not in TORCH_DISTRIBUTED_SUPPORTED_FRAMEWORK_VERSIONS:
+            err_msg += (
+                f"Provided framework_version {framework_version} is not supported by"
+                " torch_distributed.\n"
+                "Please specify one of the supported framework versions:"
+                f" {TORCH_DISTRIBUTED_SUPPORTED_FRAMEWORK_VERSIONS} \n"
+            )
+        if "py3" not in py_version:
+            err_msg += (
+                f"Provided py_version {py_version} is not supported by torch_distributed.\n"
+                "Please specify py_version>=py3"
+            )
+
+    # Check instance compatibility
+    match = re.match(r"^ml[\._]([a-z\d]+)\.?\w*$", instance_type)
+    if match:
+        if not match[1].startswith("trn"):
+            err_msg += (
+                "torch_distributed is currently supported only for trainium instances.\n"
+                " Please refer https://sagemaker.readthedocs.io/en/stable/frameworks/pytorch/using_pytorch.html#distributed-pytorch-training \n"  # noqa E501  # pylint: disable=c0301
+                "for information regarding distributed training on non-trainium instances"
+            )
+
+    # Check entry point type
+    if not entry_point.endswith(".py"):
+        err_msg += (
+            "Unsupported entry point type for the distribution torch_distributed.\n"
+            "Only python programs (*.py) are supported."
+        )
+
+    if err_msg:
+        raise ValueError(err_msg)
+
+
 def python_deprecation_warning(framework, latest_supported_version):
     """Placeholder docstring"""
     return PYTHON_2_DEPRECATION_WARNING.format(
