@@ -74,20 +74,22 @@ class Processor(object):
             role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing
                 uses this role to access AWS resources, such as
                 data stored in Amazon S3.
-            image_uri (str): The URI of the Docker image to use for the
+            image_uri (str or PipelineVariable): The URI of the Docker image to use for the
                 processing jobs.
-            instance_count (int): The number of instances to run
+            instance_count (int or PipelineVariable): The number of instances to run
                 a processing job with.
-            instance_type (str): The type of EC2 instance to use for
+            instance_type (str or PipelineVariable): The type of EC2 instance to use for
                 processing, for example, 'ml.c4.xlarge'.
-            entrypoint (list[str]): The entrypoint for the processing job (default: None).
-                This is in the form of a list of strings that make a command.
-            volume_size_in_gb (int): Size in GB of the EBS volume
+            entrypoint (list[str] or list[PipelineVariable]): The entrypoint for the
+                processing job (default: None). This is in the form of a list of strings
+                that make a command.
+            volume_size_in_gb (int or PipelineVariable): Size in GB of the EBS volume
                 to use for storing data during processing (default: 30).
-            volume_kms_key (str): A KMS key for the processing
+            volume_kms_key (str or PipelineVariable): A KMS key for the processing
                 volume (default: None).
-            output_kms_key (str): The KMS key ID for processing job outputs (default: None).
-            max_runtime_in_seconds (int): Timeout in seconds (default: None).
+            output_kms_key (str or PipelineVariable): The KMS key ID for processing job
+                outputs (default: None).
+            max_runtime_in_seconds (int or PipelineVariable): Timeout in seconds (default: None).
                 After this amount of time, Amazon SageMaker terminates the job,
                 regardless of its current status. If `max_runtime_in_seconds` is not
                 specified, the default value is 24 hours.
@@ -98,10 +100,10 @@ class Processor(object):
                 Session object which manages interactions with Amazon SageMaker and
                 any other AWS services needed. If not specified, the processor creates
                 one using the default AWS configuration chain.
-            env (dict[str, str]): Environment variables to be passed to
-                the processing jobs (default: None).
-            tags (list[dict]): List of tags to be passed to the processing job
-                (default: None). For more, see
+            env (dict[str, str] or dict[str, PipelineVariable]): Environment variables
+                to be passed to the processing jobs (default: None).
+            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags
+                to be passed to the processing job (default: None). For more, see
                 https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
             network_config (:class:`~sagemaker.network.NetworkConfig`):
                 A :class:`~sagemaker.network.NetworkConfig`
@@ -155,8 +157,8 @@ class Processor(object):
             outputs (list[:class:`~sagemaker.processing.ProcessingOutput`]): Outputs for
                 the processing job. These can be specified as either path strings or
                 :class:`~sagemaker.processing.ProcessingOutput` objects (default: None).
-            arguments (list[str]): A list of string arguments to be passed to a
-                processing job (default: None).
+            arguments (list[str] or list[PipelineVariable]): A list of string arguments
+                to be passed to a processing job (default: None).
             wait (bool): Whether the call should wait until the job completes (default: True).
             logs (bool): Whether to show the logs produced by the job.
                 Only meaningful when ``wait`` is True (default: True).
@@ -424,20 +426,21 @@ class ScriptProcessor(Processor):
             role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing
                 uses this role to access AWS resources, such as
                 data stored in Amazon S3.
-            image_uri (str): The URI of the Docker image to use for the
+            image_uri (str or PipelineVariable): The URI of the Docker image to use for the
                 processing jobs.
             command ([str]): The command to run, along with any command-line flags.
                 Example: ["python3", "-v"].
-            instance_count (int): The number of instances to run
+            instance_count (int or PipelineVariable): The number of instances to run
                 a processing job with.
-            instance_type (str): The type of EC2 instance to use for
+            instance_type (str or PipelineVariable): The type of EC2 instance to use for
                 processing, for example, 'ml.c4.xlarge'.
-            volume_size_in_gb (int): Size in GB of the EBS volume
+            volume_size_in_gb (int or PipelineVariable): Size in GB of the EBS volume
                 to use for storing data during processing (default: 30).
-            volume_kms_key (str): A KMS key for the processing
+            volume_kms_key (str or PipelineVariable): A KMS key for the processing
                 volume (default: None).
-            output_kms_key (str): The KMS key ID for processing job outputs (default: None).
-            max_runtime_in_seconds (int): Timeout in seconds (default: None).
+            output_kms_key (str or PipelineVariable): The KMS key ID for processing
+                job outputs (default: None).
+            max_runtime_in_seconds (int or PipelineVariable): Timeout in seconds (default: None).
                 After this amount of time, Amazon SageMaker terminates the job,
                 regardless of its current status. If `max_runtime_in_seconds` is not
                 specified, the default value is 24 hours.
@@ -448,10 +451,10 @@ class ScriptProcessor(Processor):
                 Session object which manages interactions with Amazon SageMaker and
                 any other AWS services needed. If not specified, the processor creates
                 one using the default AWS configuration chain.
-            env (dict[str, str]): Environment variables to be passed to
-                the processing jobs (default: None).
-            tags (list[dict]): List of tags to be passed to the processing job
-                (default: None). For more, see
+            env (dict[str, str] or dict[str, PipelineVariable])): Environment variables to
+                be passed to the processing jobs (default: None).
+            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags to
+                be passed to the processing job (default: None). For more, see
                 https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
             network_config (:class:`~sagemaker.network.NetworkConfig`):
                 A :class:`~sagemaker.network.NetworkConfig`
@@ -1108,22 +1111,23 @@ class ProcessingInput(object):
         for a processing job and provides a method to turn those parameters into a dictionary.
 
         Args:
-            source (str): The source for the input. If a local path is provided, it will
-                automatically be uploaded to S3 under:
+            source (str or PipelineVariable): The source for the input. If a local path
+                is provided, it will automatically be uploaded to S3 under:
                 "s3://<default-bucket-name>/<job-name>/input/<input-name>".
-            destination (str): The destination of the input.
-            input_name (str): The name for the input. If a name
+            destination (str or PipelineVariable): The destination of the input.
+            input_name (str or PipelineVariable): The name for the input. If a name
                 is not provided, one will be generated (eg. "input-1").
-            s3_data_type (str): Valid options are "ManifestFile" or "S3Prefix".
-            s3_input_mode (str): Valid options are "Pipe" or "File".
-            s3_data_distribution_type (str): Valid options are "FullyReplicated"
+            s3_data_type (str or PipelineVariable): Valid options are "ManifestFile" or "S3Prefix".
+            s3_input_mode (str or PipelineVariable): Valid options are "Pipe" or "File".
+            s3_data_distribution_type (str or PipelineVariable): Valid options are "FullyReplicated"
                 or "ShardedByS3Key".
-            s3_compression_type (str): Valid options are "None" or "Gzip".
+            s3_compression_type (str or PipelineVariable): Valid options are "None" or "Gzip".
             s3_input (:class:`~sagemaker.dataset_definition.inputs.S3Input`)
                 Metadata of data objects stored in S3
             dataset_definition (:class:`~sagemaker.dataset_definition.inputs.DatasetDefinition`)
                 DatasetDefinition input
-            app_managed (bool): Whether the input are managed by SageMaker or application
+            app_managed (bool or PipelineVariable): Whether the input are managed by SageMaker
+                or application
         """
         self.source = source
         self.destination = destination
@@ -1211,16 +1215,18 @@ class ProcessingOutput(object):
         processing job and provides a method to turn those parameters into a dictionary.
 
         Args:
-            source (str): The source for the output.
-            destination (str): The destination of the output. If a destination
+            source (str or PipelineVariable): The source for the output.
+            destination (str or PipelineVariable): The destination of the output. If a destination
                 is not provided, one will be generated:
                 "s3://<default-bucket-name>/<job-name>/output/<output-name>"
                 (Note: this does not apply when used with
                 :class:`~sagemaker.workflow.steps.ProcessingStep`).
-            output_name (str): The name of the output. If a name
+            output_name (str or PipelineVariable): The name of the output. If a name
                 is not provided, one will be generated (eg. "output-1").
-            s3_upload_mode (str): Valid options are "EndOfJob" or "Continuous".
-            app_managed (bool): Whether the input are managed by SageMaker or application
+            s3_upload_mode (str or PipelineVariable): Valid options are "EndOfJob"
+                or "Continuous".
+            app_managed (bool or PipelineVariable): Whether the input are managed by SageMaker
+                or application
             feature_store_output (:class:`~sagemaker.processing.FeatureStoreOutput`)
                 Configuration for processing job outputs of FeatureStore.
         """
@@ -1328,26 +1334,29 @@ class FrameworkProcessor(ScriptProcessor):
                 ``image_uri`` is provided.
             role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing uses
                 this role to access AWS resources, such as data stored in Amazon S3.
-            instance_count (int): The number of instances to run a processing job with.
-            instance_type (str): The type of EC2 instance to use for processing, for
-                example, 'ml.c4.xlarge'.
+            instance_count (int or PipelineVariable): The number of instances to run a
+                processing job with.
+            instance_type (str or PipelineVariable): The type of EC2 instance to use for
+                processing, for example, 'ml.c4.xlarge'.
             py_version (str): Python version you want to use for executing your
                 model training code. One of 'py2' or 'py3'. Defaults to 'py3'. Value
                 is ignored when ``image_uri`` is provided.
-            image_uri (str): The URI of the Docker image to use for the
+            image_uri (str or PipelineVariable): The URI of the Docker image to use for the
                 processing jobs (default: None).
             command ([str]): The command to run, along with any command-line flags
                 to *precede* the ```code script```. Example: ["python3", "-v"]. If not
                 provided, ["python"] will be chosen (default: None).
-            volume_size_in_gb (int): Size in GB of the EBS volume
+            volume_size_in_gb (int or PipelineVariable): Size in GB of the EBS volume
                 to use for storing data during processing (default: 30).
-            volume_kms_key (str): A KMS key for the processing volume (default: None).
-            output_kms_key (str): The KMS key ID for processing job outputs (default: None).
+            volume_kms_key (str or PipelineVariable): A KMS key for the processing volume
+                (default: None).
+            output_kms_key (str or PipelineVariable): The KMS key ID for processing job outputs
+                (default: None).
             code_location (str): The S3 prefix URI where custom code will be
                 uploaded (default: None). The code file uploaded to S3 is
                 'code_location/job-name/source/sourcedir.tar.gz'. If not specified, the
                 default ``code location`` is 's3://{sagemaker-default-bucket}'
-            max_runtime_in_seconds (int): Timeout in seconds (default: None).
+            max_runtime_in_seconds (int or PipelineVariable): Timeout in seconds (default: None).
                 After this amount of time, Amazon SageMaker terminates the job,
                 regardless of its current status. If `max_runtime_in_seconds` is not
                 specified, the default value is 24 hours.
@@ -1358,10 +1367,10 @@ class FrameworkProcessor(ScriptProcessor):
                 Session object which manages interactions with Amazon SageMaker and
                 any other AWS services needed. If not specified, the processor creates
                 one using the default AWS configuration chain (default: None).
-            env (dict[str, str]): Environment variables to be passed to
-                the processing jobs (default: None).
-            tags (list[dict]): List of tags to be passed to the processing job
-                (default: None). For more, see
+            env (dict[str, str] or dict[str, PipelineVariable]): Environment variables to
+                be passed to the processing jobs (default: None).
+            tags (list[dict[str, str] or list[dict[str, PipelineVariable]]): List of tags to
+                be passed to the processing job (default: None). For more, see
                 https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html.
             network_config (:class:`~sagemaker.network.NetworkConfig`):
                 A :class:`~sagemaker.network.NetworkConfig`
@@ -1594,8 +1603,8 @@ class FrameworkProcessor(ScriptProcessor):
             outputs (list[:class:`~sagemaker.processing.ProcessingOutput`]): Outputs for
                 the processing job. These can be specified as either path strings or
                 :class:`~sagemaker.processing.ProcessingOutput` objects (default: None).
-            arguments (list[str]): A list of string arguments to be passed to a
-                processing job (default: None).
+            arguments (list[str] or list[PipelineVariable]): A list of string arguments
+                to be passed to a processing job (default: None).
             wait (bool): Whether the call should wait until the job completes (default: True).
             logs (bool): Whether to show the logs produced by the job.
                 Only meaningful when wait is True (default: True).
@@ -1622,7 +1631,7 @@ class FrameworkProcessor(ScriptProcessor):
             :class:`~sagemaker.workflow.pipeline_context.PipelineSession`
         """
         s3_runproc_sh, inputs, job_name = self._pack_and_upload_code(
-            code, source_dir, dependencies, git_config, job_name, inputs
+            code, source_dir, dependencies, git_config, job_name, inputs, kms_key
         )
 
         # Submit a processing job.
@@ -1638,7 +1647,9 @@ class FrameworkProcessor(ScriptProcessor):
             kms_key=kms_key,
         )
 
-    def _pack_and_upload_code(self, code, source_dir, dependencies, git_config, job_name, inputs):
+    def _pack_and_upload_code(
+        self, code, source_dir, dependencies, git_config, job_name, inputs, kms_key=None
+    ):
         """Pack local code bundle and upload to Amazon S3."""
         if code.startswith("s3://"):
             return code, inputs, job_name
@@ -1676,6 +1687,7 @@ class FrameworkProcessor(ScriptProcessor):
         s3_runproc_sh = S3Uploader.upload_string_as_file_body(
             self._generate_framework_script(script),
             desired_s3_uri=entrypoint_s3_uri,
+            kms_key=kms_key,
             sagemaker_session=self.sagemaker_session,
         )
         logger.info("runproc.sh uploaded to %s", s3_runproc_sh)
