@@ -19,6 +19,7 @@ from functools import wraps
 from typing import Dict, Optional
 
 from sagemaker.session import Session, SessionSettings
+from sagemaker.local import LocalSession
 
 
 class _StepArguments:
@@ -67,6 +68,7 @@ class _ModelStepArguments(_StepArguments):
         self.create_model_package_request = None
         self.create_model_request = None
         self.need_runtime_repack = set()
+        self.runtime_repack_output_prefix = None
 
 
 class PipelineSession(Session):
@@ -139,17 +141,54 @@ class PipelineSession(Session):
         else:
             self.context = _JobStepArguments(func_name, request)
 
-    def init_step_arguments(self, model):
+    def init_model_step_arguments(self, model):
         """Create a `_ModelStepArguments` (if not exist) as pipeline context
 
         Args:
             model (Model or PipelineModel): A `sagemaker.model.Model`
                 or `sagemaker.pipeline.PipelineModel` instance
         """
-        if not self._context or not isinstance(self._context, _ModelStepArguments):
+        if not isinstance(self._context, _ModelStepArguments):
             self._context = _ModelStepArguments(model)
 
 
+class LocalPipelineSession(LocalSession, PipelineSession):
+    """Managing a session that executes Sagemaker pipelines and jobs locally in a pipeline context.
+
+    This class inherits from the LocalSession and PipelineSession classes.
+    When running Sagemaker pipelines locally, this class is preferred over LocalSession.
+    """
+
+    def __init__(
+        self, boto_session=None, default_bucket=None, s3_endpoint_url=None, disable_local_code=False
+    ):
+        """Initialize a ``LocalPipelineSession``.
+
+        Args:
+            boto_session (boto3.session.Session): The underlying Boto3 session which AWS service
+                calls are delegated to (default: None). If not provided, one is created with
+                default AWS configuration chain.
+            default_bucket (str): The default Amazon S3 bucket to be used by this session.
+                This will be created the next time an Amazon S3 bucket is needed (by calling
+                :func:`default_bucket`).
+                If not provided, a default bucket will be created based on the following format:
+                "sagemaker-{region}-{aws-account-id}".
+                Example: "sagemaker-my-custom-bucket".
+            s3_endpoint_url (str): Override the default endpoint URL for Amazon S3,
+                if set (default: None).
+            disable_local_code (bool): Set to True to override the default AWS configuration chain
+                to disable the `local.local_code` setting, which may not be supported for some SDK
+                features (default: False).
+        """
+
+        super().__init__(
+            boto_session=boto_session,
+            default_bucket=default_bucket,
+            s3_endpoint_url=s3_endpoint_url,
+            disable_local_code=disable_local_code,
+        )
+
+
 def runnable_by_pipeline(run_func):
     """A convenient Decorator
 
@@ -197,7 +236,7 @@ def runnable_by_pipeline(run_func):
                 UserWarning,
             )
             if run_func.__name__ in ["register", "create"]:
-                self_instance.sagemaker_session.init_step_arguments(self_instance)
+                self_instance.sagemaker_session.init_model_step_arguments(self_instance)
                 run_func(*args, **kwargs)
                 context = self_instance.sagemaker_session.context
                 self_instance.sagemaker_session.context = None
